==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QStackedLayout_shell.h <==
#ifndef QSTACKEDLAYOUT_SHELL_H
#define QSTACKEDLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qstackedlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QStackedLayout_shell : public QStackedLayout, public QtJambiShellInterface
{
public:
    QStackedLayout_shell();
    QStackedLayout_shell(QLayout* parentLayout0);
    QStackedLayout_shell(QWidget* parent0);
    ~QStackedLayout_shell() override;

    void addItem(QLayoutItem* item0) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int width0) const override;
    int indexOf(QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int arg__1) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    void setGeometry(const QRect& rect0) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    QLayoutItem* takeAt(int arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QStackedLayout_access : public QStackedLayout
{
    void __qt_addItem_QLayoutItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasHeightForWidth_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_heightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint width0) const;
    jobject __qt_itemAt_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_minimumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_takeAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
};

#endif // QSTACKEDLAYOUT_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QStackedLayout_shell.h <==
#ifndef QSTACKEDLAYOUT_SHELL_H
#define QSTACKEDLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qstackedlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QStackedLayout_shell : public QStackedLayout, public QtJambiShellInterface
{
public:
    QStackedLayout_shell();
    QStackedLayout_shell(QLayout* parentLayout0);
    QStackedLayout_shell(QWidget* parent0);
    ~QStackedLayout_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QStackedLayout_mshell;
    friend class QStackedLayout_oshell;
};


class QStackedLayout_mshell : public QStackedLayout_shell
{
public:
    using QStackedLayout_shell::QStackedLayout_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QStackedLayout_oshell : public QStackedLayout_mshell
{
public:
    using QStackedLayout_mshell::QStackedLayout_mshell;
    void addItem(QLayoutItem* item0) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int width0) const override;
    int indexOf(const QLayoutItem* arg__1) const override;
    int indexOf(const QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int arg__1) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    QLayoutItem* replaceWidget(QWidget* from0, QWidget* to1, Qt::FindChildOptions options2) override;
    void setGeometry(const QRect& rect0) override;
    void setSpacing(int arg__1) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    int spacing() const override;
    QLayoutItem* takeAt(int arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QStackedLayout_access : public QStackedLayout
{
    void __qt_addItem_QLayoutItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasHeightForWidth_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_heightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint width0) const;
    jobject __qt_itemAt_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_minimumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_takeAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
};

#endif // QSTACKEDLAYOUT_SHELL_H
